root_name

Function root_name 

pub fn root_name(source: &Path) -> Result<String>
The name the root is sent under: the last part of the path as given, else of its real path.

Errors

Fails when the path has no name or the name is not valid UTF-8.