pub struct Unpacked {
pub path: PathBuf,
pub progress: Progress,
pub skipped: SkipList,
}Expand description
What was written and where.
Fields
path: PathBufFinal path of the file or folder that was created or merged into.
progress: Progressskipped: SkipListEntries left out here, followed by the ones the sender left out.